@@ -44,6 +44,7 @@ class BytesLike(bytes):
     - https://github.com/duo-labs/py_webauthn/issues/110
     - https://github.com/duo-labs/py_webauthn/issues/113
     """
+
     @classmethod
     def __get_validators__(cls):
         yield cls.validate
@@ -52,6 +53,8 @@ class BytesLike(bytes):
     def validate(cls, v):
         if isinstance(v, bytes):
             return v
+        elif isinstance(v, memoryview):
+            return v.tobytes()
         else:
             return strict_bytes_validator(v)
 
